# Instalace Arch Linuxu s Openbox

Tento dokument poskytuje podrobný průvodce pro instalaci Arch Linuxu s Openboxem. Instalace zahrnuje šifrování celého disku s BTRFS, nastavení uživatelských účtů, konfiguraci LightDM a základní bezpečnostní nastavení.

## Obsah
1. [Příprava na instalaci](#příprava-na-instalaci)
2. [Particionace a šifrování disku](#particionace-a-šifrování-disku)
3. [Instalace základního systému](#instalace-základního-systému)
4. [Konfigurace systému](#konfigurace-systému)
5. [Instalace a konfigurace Openbox a LightDM](#instalace-a-konfigurace-openbox-a-lightdm)
6. [Nastavení uživatele a bezpečnostních nástrojů](#nastavení-uživatele-a-bezpečnostních-nástrojů)

## Příprava na instalaci
Zajistěte, že váš systém je připojen k internetu a máte přístup k archivu Arch Linuxu:
```bash
pacman -Sy
pacman -S reflector
reflector --latest 5 --sort rate --save /etc/pacman.d/mirrorlist
timedatectl set-ntp true
```

## Particionace a šifrování disku

Identifikujte cílový disk pomocí lsblk. Příklad dělení disku pro systém UEFI:

```bash
gdisk /dev/sdx
```

* Vytvořte EFI systémový oddíl (typ ef00, 512MiB)
* Vytvořte root oddíl pro Arch Linux, který bude šifrován (typ 8304)

## Nastavení šifrování LUKS

```bash
cryptsetup luksFormat /dev/sdx2
cryptsetup open /dev/sdx2 cryptroot
```
## Vytvoření BTRFS podsvazků

```bash
mkfs.btrfs /dev/mapper/cryptroot
mount /dev/mapper/cryptroot /mnt
btrfs subvolume create /mnt/@
btrfs subvolume create /mnt/@home
btrfs subvolume create /mnt/@var_log
umount /mnt
mount -o subvol=@,compress=zlib,ssd,noatime /dev/mapper/cryptroot /mnt
mkdir /mnt/home
mkdir /mnt/var/log
mount -o subvol=@home,compress=zlib,ssd,noatime /dev/mapper/cryptroot /mnt/home
mount -o subvol=@var_log,compress=zlib,ssd,noatime /dev/mapper/cryptroot /mnt/var/log
```

## Instalace základního systému

```bash
pacstrap /mnt base linux linux-firmware btrfs-progs vim
genfstab -U /mnt >> /mnt/etc/fstab
```
## Konfigurace systému
Po instalaci základního systému je nutné provést základní konfiguraci systému. Zadejte následující příkazy v prostředí `chroot`:

```bash
# Změna do chroot prostředí
arch-chroot /mnt

#Nastavení časové zóny
ln -sf /usr/share/zoneinfo/Europe/Prague /etc/localtime
hwclock --systohc

#Nastavení lokalizace systému
#Upravte soubor locale.gen a odkomentujte (nebo přidejte) řádky pro češtinu
nano /etc/locale.gen
# Odstraňte komentáře u řádků:
# cs_CZ.UTF-8 UTF-8
# cs_CZ ISO-8859-2

## Generujte lokalizace
locale-gen

## Nastavte systémový jazyk
echo "LANG=cs_CZ.UTF-8" > /etc/locale.conf
export LANG=cs_CZ.UTF-8
```
## Nastavení sítě

### Nastavte hostname a konfigurujte sítě:

```bash
echo "myhostname" > /etc/hostname
echo "127.0.0.1 localhost" >> /etc/hosts
echo "::1       localhost" >> /etc/hosts
echo "127.0.1.1 myhostname.localdomain myhostname" >> /etc/hosts
```
## Nastavení hesla root

### Nastavte heslo pro účet root:

```bash
passwd
```
Zadejte a potvrďte heslo pro účet root, které bude použito pro administrativní přístup.

## Instalace ovladačů grafické karty

Pro správnou funkci grafického prostředí je potřeba nainstalovat ovladače pro vaši grafickou kartu. Arch Linux podporuje ovladače pro většinu běžných grafických karet:

### Pro Intel grafické karty

```bash
pacman -S xf86-video-intel
```

### Pro AMD grafické karty

```bash
pacman -S xf86-video-amdgpu
```

### Pro NVIDIA grafické karty

```bash
pacman -S nvidia nvidia-utils
```

## Instalace a konfigurace NetworkManager

NetworkManager je nástroj pro snadnou konfiguraci a správu síťových připojení:

```bash
pacman -S networkmanager
systemctl enable NetworkManager.service
systemctl start NetworkManager.service
```
Tímto krokem zabezpečíte, že NetworkManager bude automaticky spuštěn při startu systému a bude dostupný pro správu síťových připojení přes grafické rozhraní nebo příkazovou řádku.



## Instalace Openbox a LightDM

 Nainstalujte grafické prostředí a správce přihlašování:
 
 ```bash
 pacman -S xorg-server xorg-xinit openbox lightdm lightdm-gtk-greeter
systemctl enable lightdm
```

## Vytvoření uživatele a nastavení sudo

Vytvořte běžného uživatele s možností používat sudo pro administrativní úkoly:

```bash
useradd -m -G wheel -s /bin/bash novyuzivatel
passwd novyuzivatel
pacman -S sudo
EDITOR=vim visudo
```
V souboru sudoers, odkomentujte řádek %wheel ALL=(ALL) ALL pro umožnění členům skupiny wheel používat příkaz sudo.

## Závěrečné kroky

Ukončete chroot a restartujte systém:

```bash
exit
umount -R /mnt
reboot
```