# Post-instalační konfigurace Arch Linuxu

Tento dokument popisuje kroky potřebné k dokončení konfigurace Arch Linuxu po základní instalaci. Zahrnuje instalaci a nastavení Pipewire, Timeshift, grub-btrfs a dalších doplňkových služeb.

## 1. Aktualizace systému

Po prvním spuštění systému je důležité provést aktualizaci balíčků, aby byly aplikovány nejnovější bezpečnostní opravy a vylepšení.

```bash
sudo pacman -Syu
```

## 2. Instalace a konfigurace Pipewire

Pipewire je moderní audio a video server, který poskytuje nízkou latenci a je navržen tak, aby byl plně kompatibilní s existujícími aplikacemi PulseAudio, JACK a ALSA.


### Instalace Pipewire

```bash
sudo pacman -S pipewire pipewire-alsa pipewire-pulse pipewire-jack pipewire-media-session
```

### Aktivace Pipewire

```
systemctl --user enable pipewire pipewire-media-session
systemctl --user start pipewire pipewire-media-session
```
## 3. Instalace yay

`yay` je pomocník pro správu balíčků z AUR (Arch User Repository), který umožňuje snadnou instalaci balíčků z AUR.
Instalace yay

### Nejprve nainstalujte potřebné závislosti:

```bash
sudo pacman -S base-devel git
```

Poté klonujte repozitář yay a nainstalujte jej:

```bash
cd /opt
sudo git clone https://aur.archlinux.org/yay.git
sudo chown -R $USER:$USER ./yay
cd yay
makepkg -si
```

## 4. Instalace a konfigurace Timeshift

Timeshift je nástroj pro správu záloh systému pomocí rsync nebo BTRFS. Umožňuje vytvářet a spravovat snapshoty systému.

### Instalace Timeshift z AUR

```bash
yay -S timeshift
```
## Aktivace Cronie

Cronie je služba používaná Timeshiftem pro pravidelné spouštění služeb. Musí být povolena.

```bash
sudo systemctl enable --now cronie.service
```

## Nastavení Timeshift

Spusťte Timeshift a nastavte jej pro použití BTRFS. Volitelně povolte automatické snapshoty a vyberte, zda chcete zahrnout složku domovského adresáře do snapshotů. Vytvořte první snapshot kliknutím na tlačítko "Create" v levém horním rohu okna.

### Instalace timeshift-autosnap z AUR

Pokud chcete automatické snapshoty před každou aktualizací balíčků/systému, nainstalujte timeshift-autosnap:

```bash
yay -S timeshift-autosnap
```
## 5. Instalace a konfigurace grub-btrfs

Instalace grub-btrfs

```bash
sudo pacman -S grub-btrfs
```

### Konfigurace grub-btrfs

Pro zahrnutí snapshotů Timeshiftu do možností bootování je potřeba přizpůsobit grub-btrfs:

```bash
sudo systemctl edit --full grub-btrfsd
```

Změňte řádek:

```bash¨
ExecStart=/usr/bin/grub-btrfsd --syslog /.snapshots
```

na:

```bash
ExecStart=/usr/bin/grub-btrfsd --syslog --timeshift-auto
```

### Rekonfigurace GRUB a aktivace služby

```bash
sudo grub-mkconfig -o /boot/grub/grub.cfg
sudo systemctl enable --now grub-btrfsd
```

Uložte soubor stisknutím Ctrl+X a potvrzením výzev.

## 6. Základní utility

Instalace základních utilit, které usnadní práci s systémem.

```bash
sudo pacman -S git curl wget
```

## 7. Bezpečnostní nastavení

Instalace a nastavení `ufw` (Uncomplicated Firewall) pro základní ochranu síťového provozu.

```bash
sudo pacman -S ufw
sudo ufw enable
sudo ufw default deny incoming
sudo ufw default allow outgoing
```

## 8. Instalace nástrojů pro sledování systému

### Htop

Htop je interaktivní systémový monitor, který zobrazuje využití CPU, paměti a další informace o běžících procesech.

```bash
sudo pacman -S htop
```

## 9. Konfigurace Pacman a Reflector

### Nastavení Pacman

Upravte /etc/pacman.conf pro lepší uživatelský zážitek:

```bash
sudo nano /etc/pacman.conf
```

Přidejte nebo upravte následující řádky:

```bash
Color
CheckSpace
VerbosePkgLists
ILoveCandy
ParallelDownloads = 7
SigLevel = Required DatabaseOptional
```

### Aktivace multilib, extra, community repozitářů

```bash
[multilib]
Include = /etc/pacman.d/mirrorlist

[extra]
Include = /etc/pacman.d/mirrorlist

[community]
Include = /etc/pacman.d/mirrorlist

[multilib-testing]
Include = /etc/pacman.d/mirrorlist
```

Poté aktualizujte seznam balíčků:

```bash
sudo pacman -Syy
```

### Nastavení Reflector

Reflector je nástroj, který automaticky aktualizuje seznam zrcadel pro Pacman podle rychlosti a dostupnosti.

Instalace Reflector:

```bash
sudo pacman -S reflector
```

Konfigurace Reflector:

```bash
sudo reflector --latest 5 --sort rate --save /etc/pacman.d/mirrorlist
```

Pro automatické aktualizace můžete přidat cron úlohu pro Reflector:

```bash
sudo systemctl enable --now reflector.timer
```

## 10. Doporučené kroky z Arch Wiki

Arch Wiki poskytuje podrobný seznam doporučených kroků pro konfiguraci a údržbu systému. Zde jsou některé z nich:

### Zálohování

Nastavení pravidelného zálohování je klíčové pro ochranu vašich dat. Kromě Timeshift můžete zvážit použití dalších nástrojů jako `rsync` nebo `borg`.

### Výměnný oddíl (Swap)

Pokud jste nevytvořili swap oddíl během instalace, můžete vytvořit swap soubor:

```bash
sudo fallocate -l 4G /swapfile
sudo chmod 600 /swapfile
sudo mkswap /swapfile
sudo swapon /swapfile
echo '/swapfile none swap defaults 0 0' | sudo tee -a /etc/fstab
```

### DNS Cache

Pro zrychlení načítání webových stránek můžete nainstalovat a nakonfigurovat DNS cache, například systemd-resolved:

```bash
sudo pacman -S systemd-resolved
sudo systemctl enable --now systemd-resolved
sudo ln -sf /run/systemd/resolve/stub-resolv.conf /etc/resolv.conf
```

### Další tipy

Další tipy a podrobnosti naleznete na stránce [General recommendations](https://wiki.archlinux.org/title/General_recommendations) na Arch Wiki.

## 11. Tipy a údržba systému

Pravidelná údržba systému je důležitá pro udržení jeho výkonu a bezpečnosti. Doporučujeme vytvořit skript pro základní údržbu, který bude zahrnovat aktualizace, čištění cache a odstraňování sirotčích balíčků.

### Skript pro základní údržbu 

Skript pro základní údržbu

Skript system_maintenance.sh můžete stáhnout pomocí wget:

```bash
wget https://git.arch-linux.cz/Archos/Archlinux_Openbox/src/branch/main/POST-INSTALL/system_maintenance.sh
chmod +x system_maintenance.sh
```

Tento skript obsahuje následující obsah:

```bash
#!/bin/bash

# Aktualizace systému
echo "Aktualizace systému..."
sudo pacman -Syu --noconfirm

# Čištění cache
echo "Čištění cache..."
sudo pacman -Sc --noconfirm

# Odstranění sirotčích balíčků
echo "Odstranění sirotčích balíčků..."
sudo pacman -Rns $(pacman -Qtdq) --noconfirm

echo "Údržba systému dokončena."
```

Tento skript je základní a může být v budoucnu rozšířen o další funkce pro pokročilejší údržbu systému.
Nastavení skriptu pro spuštění

1.  Uložte skript do vašeho domovského adresáře nebo jiného vhodného umístění.
    
2. Ujistěte se, že skript má správná oprávnění pro spuštění:

```bash
chmod +x ~/system_maintenance.sh
```

### Automatické spouštění skriptu pomocí Cronie

Nastavte cron úlohu, aby spouštěla skript každou neděli ve 20:00. Upravte cron tabulku pomocí příkazu:

```
crontab -e
```

Přidejte následující řádek do crontabu:

```bash
0 20 * * 0 /path/to/your/system_maintenance.sh
```

Tento řádek zajistí, že skript system_maintenance.sh bude spuštěn každou neděli ve 20:00. Ujistěte se, že /path/to/your/system_maintenance.sh je správná cesta k vašemu skriptu.